@@ -1,6 +1,8 @@
 #!perl -w
-
 use strict;
+use FindBin qw($Bin);
+use lib "$Bin/../lib";
+
 use Acme::Perl::VM;
 
 sub f{
@@ -13,8 +15,10 @@ run_block {
 	local $| = 1;
 
 	my $sum = 0;
-	foreach my $i(1 .. 1000){
-		$sum += f($i);
+	foreach my $i(1 .. 100){
+		foreach my $j(1 .. 10){
+			$sum += f($i * $j);
+		}
 	}
 
 	print "\n", $sum, "\n";
