@@ -1,6 +1,9 @@
 #!perl -w
 BEGIN{ $ENV{APVM_DEBUG} = 'trace' }
 use strict;
+use FindBin qw($Bin);
+use lib "$Bin/../lib";
+
 use Acme::Perl::VM::Run;
 
 sub Foo::hello{
