@@ -134,7 +134,7 @@ sub pp_rv2sv{
 	}
 
 	if($PL_op->flags & OPf_MOD){
-		if($PL_op->op_private & OPpLVAL_INTRO){
+		if($PL_op->private & OPpLVAL_INTRO){
 			if($PL_op->first->name eq 'null'){
 				$sv = save_scalar(TOP);
 			}
@@ -1099,6 +1099,12 @@ sub pp_or{
 	}
 }
 
+sub pp_stringify{
+	my $sv = TOP;
+	SETval(SvPV($sv));
+	return $PL_op->next;
+}
+
 sub pp_defined{
 	if($PL_op->name ne 'defined'){ # dor/dorassign
 		not_implemented 'dor';
@@ -1398,7 +1404,7 @@ sub pp_shift{
 	mPUSH(svref_2object(\$val));
 	return $PL_op->next;
 }
-	
+
 sub pp_unshift{
 	my $mark = POPMARK;
 	my $av   = $PL_stack[++$mark];
@@ -1407,6 +1413,14 @@ sub pp_unshift{
 	return $PL_op->next;
 }
 
+sub pp_join{
+	my $mark = POPMARK;
+
+	my $delim = $PL_stack[++$mark];
+	SETval(join SvPV($delim), mark_list($mark));
+	return $PL_op->next;
+}
+
 sub pp_aelemfast{
 	my $av   = $PL_op->flags & OPf_SPECIAL ? PAD_SV($PL_op->targ) : GVOP_gv($PL_op)->AV;
 	my $lval = $PL_op->flags & OPf_MOD || LVRET;
